@@ -5,7 +5,7 @@ use base 'PPI::Token';
 
 use vars qw{$VERSION %QUOTELIKE %OPERATOR};
 BEGIN {
-	$VERSION = '0.845';
+	$VERSION = '0.846';
 
 	%QUOTELIKE = (
 		'q'  => 'Quote::Literal',
@@ -32,6 +32,13 @@ sub _on_char {
 	if ( $line =~ /^(\w+(?:(?:\'|::)[^\W\d]\w*)*(?:::)?)/ ) {
 		$t->{token}->{content} .= $1;
 		$t->{line_cursor} += length $1;
+
+		# Special Case: If we accidentally treat eq'foo' like the word "eq'foo",
+		# then unwind it and just make it 'eq' (or the other stringy comparitors)
+		if ( $t->{token}->{content} =~ /^(?:eq|ne|q|qq|qx|qw|qr|m|s|tr|y)\'/ ) {
+			$t->{line_cursor} -= ($t->{token}->{content} - 2);
+			$t->{token}->{content} = substr($t->{token}->{content}, 0, 2);
+		}
 	}
 
 	# We might be a subroutine attribute.
@@ -92,8 +99,14 @@ sub _commit {
 		die "Fatal error... regex failed to match when expected";
 	}
 
-	# Advance the position one after the end of the bareword
+	# Special Case: If we accidentally treat eq'foo' like the word "eq'foo",
+	# then unwind it and just make it 'eq' (or the other stringy comparitors)
 	my $word = $1;
+	if ( $word =~ /^(?:eq|ne|q|qq|qx|qw|qr|m|s|tr|y)\'/ ) {
+		$word = substr($word, 0, 2);
+	}
+
+	# Advance the position one after the end of the bareword
 	$t->{line_cursor} += length $word;
 
 	# We might be a subroutine attribute.
